/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 *  Copyright (C) 2005 HIGUCHI Daisuke
 *  Copyright (C) 2006 Juernjakob Harder
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TOMOE_GTK_H_INCLUDED__
#define __TOMOE_GTK_H_INCLUDED__

#include <tomoe-canvas.h>
#include <tomoe-char-table.h>
#include <tomoe-window.h>
#include <tomoe-stroke-search.h>

#endif /* __TOMOE_GTK_H_INCLUDED__ */
